summaryrefslogtreecommitdiffstats
path: root/kmplot
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
commit648ba4a456d3aad2825193ff8f3bd52a875783b5 (patch)
tree0b50d2253a0c85238cc4dcba5c4f949de3f0eb15 /kmplot
parent98a12d05a48814bec3870b9a6d5865475cfa1c95 (diff)
downloadtdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.tar.gz
tdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1212481 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmplot')
-rw-r--r--kmplot/kmplot/FktDlgData.ui14
-rw-r--r--kmplot/kmplot/MainDlg.cpp20
-rw-r--r--kmplot/kmplot/MainDlg.h8
-rw-r--r--kmplot/kmplot/Makefile.am2
-rw-r--r--kmplot/kmplot/View.cpp12
-rw-r--r--kmplot/kmplot/View.h2
-rw-r--r--kmplot/kmplot/diagr.cpp6
-rw-r--r--kmplot/kmplot/editderivativespage.ui6
-rw-r--r--kmplot/kmplot/editfunction.cpp2
-rw-r--r--kmplot/kmplot/editfunctionpage.ui98
-rw-r--r--kmplot/kmplot/editintegralpage.ui6
-rw-r--r--kmplot/kmplot/kconstanteditor.cpp2
-rw-r--r--kmplot/kmplot/keditparametric.cpp2
-rw-r--r--kmplot/kmplot/kminmax.cpp12
-rw-r--r--kmplot/kmplot/kmplot.cpp2
-rw-r--r--kmplot/kmplot/kprinterdlg.cpp12
-rw-r--r--kmplot/kmplot/parser.cpp6
-rw-r--r--kmplot/kmplot/parser.h4
-rw-r--r--kmplot/kmplot/qconstanteditor.ui6
-rw-r--r--kmplot/kmplot/qeditconstant.ui8
-rw-r--r--kmplot/kmplot/qeditparametric.ui12
-rw-r--r--kmplot/kmplot/qeditpolar.ui6
-rw-r--r--kmplot/kmplot/qminmax.ui8
-rw-r--r--kmplot/kmplot/qparametereditor.ui8
-rw-r--r--kmplot/kmplot/settingspagecolor.ui18
-rw-r--r--kmplot/kmplot/settingspagecoords.ui24
-rw-r--r--kmplot/kmplot/settingspagefonts.ui6
-rw-r--r--kmplot/kmplot/settingspageprecision.ui10
-rw-r--r--kmplot/kmplot/settingspagescaling.ui8
-rw-r--r--kmplot/kmplot/sliderwindow.ui10
-rw-r--r--kmplot/kmplot/xparser.cpp2
31 files changed, 171 insertions, 171 deletions
diff --git a/kmplot/kmplot/FktDlgData.ui b/kmplot/kmplot/FktDlgData.ui
index 7624f2de..9678e889 100644
--- a/kmplot/kmplot/FktDlgData.ui
+++ b/kmplot/kmplot/FktDlgData.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>FktDlgData</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -12,7 +12,7 @@
<height>355</height>
</rect>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>350</width>
<height>250</height>
@@ -33,7 +33,7 @@
</property>
<widget class="QLayoutWidget" row="1" column="0">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -57,7 +57,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -262,7 +262,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -329,7 +329,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -417,7 +417,7 @@
<slot access="protected">slotHelp()</slot>
<slot>slotNewPrime()</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klistview.h</includehint>
</includehints>
diff --git a/kmplot/kmplot/MainDlg.cpp b/kmplot/kmplot/MainDlg.cpp
index 83a09080..e8916f93 100644
--- a/kmplot/kmplot/MainDlg.cpp
+++ b/kmplot/kmplot/MainDlg.cpp
@@ -63,13 +63,13 @@ class KmPlotIO;
bool MainDlg::oldfileversion;
-MainDlg::MainDlg(TQWidget *tqparentWidget, const char *, TQObject *parent, const char *name) : DCOPObject( "MainDlg" ), KParts::ReadOnlyPart( parent, name ), m_recentFiles( 0 ), m_modified(false), m_parent(tqparentWidget)
+MainDlg::MainDlg(TQWidget *parentWidget, const char *, TQObject *parent, const char *name) : DCOPObject( "MainDlg" ), KParts::ReadOnlyPart( parent, name ), m_recentFiles( 0 ), m_modified(false), m_parent(parentWidget)
{
// we need an instance
setInstance( KmPlotPartFactory::instance() );
- kdDebug() << "tqparentWidget->name():" << tqparentWidget->name() << endl;
- if ( TQString(tqparentWidget->name()).startsWith("KmPlot") )
+ kdDebug() << "parentWidget->name():" << parentWidget->name() << endl;
+ if ( TQString(parentWidget->name()).startsWith("KmPlot") )
{
setXMLFile("kmplot_part.rc");
m_readonly = false;
@@ -82,14 +82,14 @@ MainDlg::MainDlg(TQWidget *tqparentWidget, const char *, TQObject *parent, const
}
fdlg = 0;
coordsDialog = 0;
- m_popupmenu = new KPopupMenu(tqparentWidget);
- view = new View( m_readonly, m_modified, m_popupmenu, tqparentWidget );
+ m_popupmenu = new KPopupMenu(parentWidget);
+ view = new View( m_readonly, m_modified, m_popupmenu, parentWidget );
connect( view, TQT_SIGNAL( setStatusBarText(const TQString &)), this, TQT_SLOT( setReadOnlyStatusBarText(const TQString &) ) );
setWidget( view );
view->setFocusPolicy(TQWidget::ClickFocus);
minmaxdlg = new KMinMax(view, m_parent);
view->setMinMaxDlg(minmaxdlg);
- m_quickEdit = new KLineEdit( tqparentWidget );
+ m_quickEdit = new KLineEdit( parentWidget );
m_quickEdit->setFocus();
TQToolTip::add( m_quickEdit, i18n( "Enter a function equation, for example: f(x)=x^2" ) );
setupActions();
@@ -99,7 +99,7 @@ MainDlg::MainDlg(TQWidget *tqparentWidget, const char *, TQObject *parent, const
m_recentFiles->loadEntries( m_config );
// Let's create a Configure Diloag
- m_settingsDialog = new KConfigDialog( tqparentWidget, "settings", Settings::self() );
+ m_settingsDialog = new KConfigDialog( parentWidget, "settings", Settings::self() );
m_settingsDialog->setHelp("general-config");
// create and add the page(s)
@@ -538,7 +538,7 @@ void MainDlg::slotQuickEdit(const TQString& f_str_const )
KMessageBox::error( m_parent, i18n("Parametric functions must be definied in the \"New Parametric Plot\"-dialog which you can find in the menubar"));
return;
}
- if ( f_str.tqcontains('y') != 0)
+ if ( f_str.contains('y') != 0)
{
KMessageBox::error( m_parent, i18n( "Recursive function is not allowed"));
m_quickEdit->setFocus();
@@ -785,12 +785,12 @@ KmPlotPartFactory::~KmPlotPartFactory()
s_instance = 0L;
}
-KParts::Part* KmPlotPartFactory::createPartObject( TQWidget *tqparentWidget, const char *widgetName,
+KParts::Part* KmPlotPartFactory::createPartObject( TQWidget *parentWidget, const char *widgetName,
TQObject *parent, const char *name,
const char *, const TQStringList & )
{
// Create an instance of our Part
- MainDlg* obj = new MainDlg( tqparentWidget, widgetName, parent, name );
+ MainDlg* obj = new MainDlg( parentWidget, widgetName, parent, name );
emit objectCreated( obj );
return obj;
}
diff --git a/kmplot/kmplot/Makefile.am b/kmplot/kmplot/Makefile.am
index 27b903a4..f5158dc9 100644
--- a/kmplot/kmplot/Makefile.am
+++ b/kmplot/kmplot/Makefile.am
@@ -45,7 +45,7 @@ kde_module_LTLIBRARIES = libkmplotpart.la
# the Part's source, library search path, and link libraries
libkmplotpart_la_SOURCES = FktDlgData.ui parser.cpp xparser.cpp diagr.cpp View.cpp MainDlg.cpp FktDlg.cpp kprinterdlg.cpp settings.kcfgc settingspagecolor.ui kconstanteditor.cpp qparametereditor.ui kparametereditor.cpp settingspagecoords.ui settingspagefonts.ui settingspagescaling.ui settingspageprecision.ui qeditparametric.ui keditparametric.cpp qeditpolar.ui keditpolar.cpp editfunctionpage.ui editderivativespage.ui editintegralpage.ui editfunction.cpp qeditconstant.ui qminmax.ui kminmax.cpp qconstanteditor.ui keditconstant.cpp kmplotio.cpp sliderwindow.ui ksliderwindow.cpp MainDlgIface.skel parseriface.skel Viewiface.skel coordsconfigdialog.cpp
libkmplotpart_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
-libkmplotpart_la_LIBADD = $(LIB_KFILE) $(LIB_KDEUI) $(LIB_KDECORE) $(LIB_QT) $(LIBSOCKET) $(LIB_KDEPRINT) -lDCOP $(LIB_KPARTS)
+libkmplotpart_la_LIBADD = $(LIB_KFILE) $(LIB_KDEUI) $(LIB_KDECORE) $(LIB_QT) $(LIBSOCKET) $(LIB_KDEPRINT)
# this is where the desktop file will go
partdesktopdir = $(kde_servicesdir)
diff --git a/kmplot/kmplot/View.cpp b/kmplot/kmplot/View.cpp
index e0b3ac5e..0d45fd2c 100644
--- a/kmplot/kmplot/View.cpp
+++ b/kmplot/kmplot/View.cpp
@@ -140,7 +140,7 @@ void View::draw(TQPaintDevice *dev, int form)
DC.resetXForm();
DC.scale((float)w/(float)(lx+2*ref.x()), (float)w/(float)(lx+2*ref.x()));
}
- wm=DC.tqworldMatrix();
+ wm=DC.worldMatrix();
s=DC.xForm(TQPoint(1000, 0)).x()/1000.;
dgr.Create( ref, lx, ly, xmin, xmax, ymin, ymax );
}
@@ -531,7 +531,7 @@ void View::setpi(TQString *s)
int i;
TQChar c(960);
- while((i=s->find('p')) != -1) s->tqreplace(i, 2, &c, 1);
+ while((i=s->find('p')) != -1) s->replace(i, 2, &c, 1);
}
@@ -639,7 +639,7 @@ void View::mouseMoveEvent(TQMouseEvent *e)
csflg=0;
}
- if(area.tqcontains(e->pos()) || (e->button()==Qt::LeftButton && e->state()==Qt::LeftButton && csxpos>xmin && csxpos<xmax))
+ if(area.contains(e->pos()) || (e->button()==Qt::LeftButton && e->state()==Qt::LeftButton && csxpos>xmin && csxpos<xmax))
{
TQPoint ptd, ptl;
TQPainter DC;
@@ -887,10 +887,10 @@ void View::mousePressEvent(TQMouseEvent *e)
it->setParameter( sw->slider->value() );
}
- if ( function_type=='x' && fabs(csxpos-m_parser->fkt(it, csxpos))< g && it->fstr.tqcontains('t')==1) //parametric plot
+ if ( function_type=='x' && fabs(csxpos-m_parser->fkt(it, csxpos))< g && it->fstr.contains('t')==1) //parametric plot
{
TQValueVector<Ufkt>::iterator ufkt_y = it+1;
- if ( fabs(csypos-m_parser->fkt(ufkt_y, csxpos)<g) && ufkt_y->fstr.tqcontains('t')==1)
+ if ( fabs(csypos-m_parser->fkt(ufkt_y, csxpos)<g) && ufkt_y->fstr.contains('t')==1)
{
if ( csmode == -1)
{
@@ -1681,7 +1681,7 @@ void View::areaUnderGraph( Ufkt *ufkt, char const p_mode, double &dmin, double
else
forward_direction = true;
- int intervals = tqRound((dmax-dmin)/dx);
+ int intervals = qRound((dmax-dmin)/dx);
int at = 0;
while ((at<=intervals) || (p_mode == 3 && x>=dmin && !forward_direction) || (p_mode == 3 && x<=dmax && forward_direction))
diff --git a/kmplot/kmplot/View.h b/kmplot/kmplot/View.h
index 63785656..a28aadbc 100644
--- a/kmplot/kmplot/View.h
+++ b/kmplot/kmplot/View.h
@@ -59,7 +59,7 @@ enum ZoomMode
};
/**
- * @short This class tqcontains the plots.
+ * @short This class contains the plots.
*
* It is the central widget of MainDlg.
* @see MainDlg, MainDlg::view
diff --git a/kmplot/kmplot/diagr.cpp b/kmplot/kmplot/diagr.cpp
index 8f03961a..ba65fce8 100644
--- a/kmplot/kmplot/diagr.cpp
+++ b/kmplot/kmplot/diagr.cpp
@@ -45,9 +45,9 @@ int isinf(double x)
CDiagr::CDiagr()
{
- frameColor=tqRgb(0, 0, 0);
- axesColor=tqRgb(0, 0, 0);
- gridColor=tqRgb(192, 192, 192);
+ frameColor=qRgb(0, 0, 0);
+ axesColor=qRgb(0, 0, 0);
+ gridColor=qRgb(192, 192, 192);
borderThickness=2;
axesLineWidth = Settings::axesLineWidth();
gridLineWidth = Settings::gridLineWidth();
diff --git a/kmplot/kmplot/editderivativespage.ui b/kmplot/kmplot/editderivativespage.ui
index 7e257f93..a6a88b78 100644
--- a/kmplot/kmplot/editderivativespage.ui
+++ b/kmplot/kmplot/editderivativespage.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>EditDerivativesPage</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -217,7 +217,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>110</height>
@@ -268,7 +268,7 @@
<tabstop>lineWidthDerivative2</tabstop>
<tabstop>colorDerivative2</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/kmplot/kmplot/editfunction.cpp b/kmplot/kmplot/editfunction.cpp
index 8100d742..2d75cc49 100644
--- a/kmplot/kmplot/editfunction.cpp
+++ b/kmplot/kmplot/editfunction.cpp
@@ -296,7 +296,7 @@ void EditFunction::accept()
tmp_ufkt.f2_linewidth = editderivativespage->lineWidthDerivative2->value();
tmp_ufkt.f2_color = editderivativespage->colorDerivative2->color().rgb();
- if ( f_str.tqcontains('y') != 0 && ( tmp_ufkt.f_mode || tmp_ufkt.f1_mode || tmp_ufkt.f2_mode) )
+ if ( f_str.contains('y') != 0 && ( tmp_ufkt.f_mode || tmp_ufkt.f1_mode || tmp_ufkt.f2_mode) )
{
KMessageBox::error( this, i18n( "Recursive function is only allowed when drawing integral graphs") );
return;
diff --git a/kmplot/kmplot/editfunctionpage.ui b/kmplot/kmplot/editfunctionpage.ui
index 6b8ff03f..31d9bd28 100644
--- a/kmplot/kmplot/editfunctionpage.ui
+++ b/kmplot/kmplot/editfunctionpage.ui
@@ -7,7 +7,7 @@
<property name="enabled">
<bool>true</bool>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -366,7 +366,7 @@ Example: f(x)=x^2</string>
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -418,14 +418,14 @@ Example: f(x)=x^2</string>
<slot access="public" specifier="">update()</slot>
<slot access="public" specifier="">update(int,int,int,int)</slot>
<slot access="public" specifier="">update(const QRect&amp;)</slot>
- <slot access="public" specifier="">tqrepaint()</slot>
- <slot access="public" specifier="">tqrepaint(bool)</slot>
- <slot access="public" specifier="">tqrepaint(int,int,int,int)</slot>
- <slot access="public" specifier="">tqrepaint(int,int,int,int,bool)</slot>
- <slot access="public" specifier="">tqrepaint(const QRect&amp;)</slot>
- <slot access="public" specifier="">tqrepaint(const QRect&amp;,bool)</slot>
- <slot access="public" specifier="">tqrepaint(const QRegion&amp;)</slot>
- <slot access="public" specifier="">tqrepaint(const QRegion&amp;,bool)</slot>
+ <slot access="public" specifier="">repaint()</slot>
+ <slot access="public" specifier="">repaint(bool)</slot>
+ <slot access="public" specifier="">repaint(int,int,int,int)</slot>
+ <slot access="public" specifier="">repaint(int,int,int,int,bool)</slot>
+ <slot access="public" specifier="">repaint(const QRect&amp;)</slot>
+ <slot access="public" specifier="">repaint(const QRect&amp;,bool)</slot>
+ <slot access="public" specifier="">repaint(const QRegion&amp;)</slot>
+ <slot access="public" specifier="">repaint(const QRegion&amp;,bool)</slot>
<slot access="public" specifier="">show()</slot>
<slot access="public" specifier="">hide()</slot>
<slot access="public" specifier="">setShown(bool)</slot>
@@ -466,7 +466,7 @@ Example: f(x)=x^2</string>
<slot access="public" specifier="">setPalette(const QPalette&amp;)</slot>
<slot access="public" specifier="">setSelection(int,int)</slot>
<slot access="public" specifier="">setCursorPosition(int)</slot>
- <slot access="public" specifier="">tqsetAlignment(int)</slot>
+ <slot access="public" specifier="">setAlignment(int)</slot>
<slot access="public" specifier="">cut()</slot>
<slot access="public" specifier="">copy()</slot>
<slot access="public" specifier="">paste()</slot>
@@ -490,10 +490,10 @@ Example: f(x)=x^2</string>
<slot access="private" specifier="">setTextWorkaround(const QString&amp;)</slot>
<property type="CString">name</property>
<property type="Bool">enabled</property>
- <property type="Rect">tqgeometry</property>
+ <property type="Rect">geometry</property>
<property type="SizePolicy">sizePolicy</property>
- <property type="Size">tqminimumSize</property>
- <property type="Size">tqmaximumSize</property>
+ <property type="Size">minimumSize</property>
+ <property type="Size">maximumSize</property>
<property type="Size">sizeIncrement</property>
<property type="Size">baseSize</property>
<property type="Color">paletteForegroundColor</property>
@@ -519,7 +519,7 @@ Example: f(x)=x^2</string>
<property type="Bool">frame</property>
<property type="EchoMode">echoMode</property>
<property type="Int">cursorPosition</property>
- <property type="Alignment">tqalignment</property>
+ <property type="Alignment">alignment</property>
<property type="Bool">dragEnabled</property>
<property type="Bool">readOnly</property>
<property type="String">inputMask</property>
@@ -565,14 +565,14 @@ Example: f(x)=x^2</string>
<slot access="public" specifier="">update()</slot>
<slot access="public" specifier="">update(int,int,int,int)</slot>
<slot access="public" specifier="">update(const QRect&amp;)</slot>
- <slot access="public" specifier="">tqrepaint()</slot>
- <slot access="public" specifier="">tqrepaint(bool)</slot>
- <slot access="public" specifier="">tqrepaint(int,int,int,int)</slot>
- <slot access="public" specifier="">tqrepaint(int,int,int,int,bool)</slot>
- <slot access="public" specifier="">tqrepaint(const QRect&amp;)</slot>
- <slot access="public" specifier="">tqrepaint(const QRect&amp;,bool)</slot>
- <slot access="public" specifier="">tqrepaint(const QRegion&amp;)</slot>
- <slot access="public" specifier="">tqrepaint(const QRegion&amp;,bool)</slot>
+ <slot access="public" specifier="">repaint()</slot>
+ <slot access="public" specifier="">repaint(bool)</slot>
+ <slot access="public" specifier="">repaint(int,int,int,int)</slot>
+ <slot access="public" specifier="">repaint(int,int,int,int,bool)</slot>
+ <slot access="public" specifier="">repaint(const QRect&amp;)</slot>
+ <slot access="public" specifier="">repaint(const QRect&amp;,bool)</slot>
+ <slot access="public" specifier="">repaint(const QRegion&amp;)</slot>
+ <slot access="public" specifier="">repaint(const QRegion&amp;,bool)</slot>
<slot access="public" specifier="">show()</slot>
<slot access="public" specifier="">hide()</slot>
<slot access="public" specifier="">setShown(bool)</slot>
@@ -606,10 +606,10 @@ Example: f(x)=x^2</string>
<slot access="protected" specifier="">chooseColor()</slot>
<property type="CString">name</property>
<property type="Bool">enabled</property>
- <property type="Rect">tqgeometry</property>
+ <property type="Rect">geometry</property>
<property type="SizePolicy">sizePolicy</property>
- <property type="Size">tqminimumSize</property>
- <property type="Size">tqmaximumSize</property>
+ <property type="Size">minimumSize</property>
+ <property type="Size">maximumSize</property>
<property type="Size">sizeIncrement</property>
<property type="Size">baseSize</property>
<property type="Color">paletteForegroundColor</property>
@@ -671,14 +671,14 @@ Example: f(x)=x^2</string>
<slot access="public" specifier="">update()</slot>
<slot access="public" specifier="">update(int,int,int,int)</slot>
<slot access="public" specifier="">update(const QRect&amp;)</slot>
- <slot access="public" specifier="">tqrepaint()</slot>
- <slot access="public" specifier="">tqrepaint(bool)</slot>
- <slot access="public" specifier="">tqrepaint(int,int,int,int)</slot>
- <slot access="public" specifier="">tqrepaint(int,int,int,int,bool)</slot>
- <slot access="public" specifier="">tqrepaint(const QRect&amp;)</slot>
- <slot access="public" specifier="">tqrepaint(const QRect&amp;,bool)</slot>
- <slot access="public" specifier="">tqrepaint(const QRegion&amp;)</slot>
- <slot access="public" specifier="">tqrepaint(const QRegion&amp;,bool)</slot>
+ <slot access="public" specifier="">repaint()</slot>
+ <slot access="public" specifier="">repaint(bool)</slot>
+ <slot access="public" specifier="">repaint(int,int,int,int)</slot>
+ <slot access="public" specifier="">repaint(int,int,int,int,bool)</slot>
+ <slot access="public" specifier="">repaint(const QRect&amp;)</slot>
+ <slot access="public" specifier="">repaint(const QRect&amp;,bool)</slot>
+ <slot access="public" specifier="">repaint(const QRegion&amp;)</slot>
+ <slot access="public" specifier="">repaint(const QRegion&amp;,bool)</slot>
<slot access="public" specifier="">show()</slot>
<slot access="public" specifier="">hide()</slot>
<slot access="public" specifier="">setShown(bool)</slot>
@@ -713,10 +713,10 @@ Example: f(x)=x^2</string>
<slot access="private" specifier="">slotEmitRelativeValueChanged(int)</slot>
<property type="CString">name</property>
<property type="Bool">enabled</property>
- <property type="Rect">tqgeometry</property>
+ <property type="Rect">geometry</property>
<property type="SizePolicy">sizePolicy</property>
- <property type="Size">tqminimumSize</property>
- <property type="Size">tqmaximumSize</property>
+ <property type="Size">minimumSize</property>
+ <property type="Size">maximumSize</property>
<property type="Size">sizeIncrement</property>
<property type="Size">baseSize</property>
<property type="Color">paletteForegroundColor</property>
@@ -777,14 +777,14 @@ Example: f(x)=x^2</string>
<slot access="public" specifier="">update()</slot>
<slot access="public" specifier="">update(int,int,int,int)</slot>
<slot access="public" specifier="">update(const QRect&amp;)</slot>
- <slot access="public" specifier="">tqrepaint()</slot>
- <slot access="public" specifier="">tqrepaint(bool)</slot>
- <slot access="public" specifier="">tqrepaint(int,int,int,int)</slot>
- <slot access="public" specifier="">tqrepaint(int,int,int,int,bool)</slot>
- <slot access="public" specifier="">tqrepaint(const QRect&amp;)</slot>
- <slot access="public" specifier="">tqrepaint(const QRect&amp;,bool)</slot>
- <slot access="public" specifier="">tqrepaint(const QRegion&amp;)</slot>
- <slot access="public" specifier="">tqrepaint(const QRegion&amp;,bool)</slot>
+ <slot access="public" specifier="">repaint()</slot>
+ <slot access="public" specifier="">repaint(bool)</slot>
+ <slot access="public" specifier="">repaint(int,int,int,int)</slot>
+ <slot access="public" specifier="">repaint(int,int,int,int,bool)</slot>
+ <slot access="public" specifier="">repaint(const QRect&amp;)</slot>
+ <slot access="public" specifier="">repaint(const QRect&amp;,bool)</slot>
+ <slot access="public" specifier="">repaint(const QRegion&amp;)</slot>
+ <slot access="public" specifier="">repaint(const QRegion&amp;,bool)</slot>
<slot access="public" specifier="">show()</slot>
<slot access="public" specifier="">hide()</slot>
<slot access="public" specifier="">setShown(bool)</slot>
@@ -818,10 +818,10 @@ Example: f(x)=x^2</string>
<slot access="private" specifier="">slotSettingsChanged(int)</slot>
<property type="CString">name</property>
<property type="Bool">enabled</property>
- <property type="Rect">tqgeometry</property>
+ <property type="Rect">geometry</property>
<property type="SizePolicy">sizePolicy</property>
- <property type="Size">tqminimumSize</property>
- <property type="Size">tqmaximumSize</property>
+ <property type="Size">minimumSize</property>
+ <property type="Size">maximumSize</property>
<property type="Size">sizeIncrement</property>
<property type="Size">baseSize</property>
<property type="Color">paletteForegroundColor</property>
@@ -897,7 +897,7 @@ Example: f(x)=x^2</string>
<slot>slotHelp()</slot>
<slot>customRange_toggled( bool )</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>kpushbutton.h</includehint>
diff --git a/kmplot/kmplot/editintegralpage.ui b/kmplot/kmplot/editintegralpage.ui
index 3a8be1cf..5180a8d2 100644
--- a/kmplot/kmplot/editintegralpage.ui
+++ b/kmplot/kmplot/editintegralpage.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>EditIntegralPage</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -229,7 +229,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>62</height>
@@ -281,7 +281,7 @@
<tabstop>lineWidth</tabstop>
<tabstop>color</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
</includehints>
diff --git a/kmplot/kmplot/kconstanteditor.cpp b/kmplot/kmplot/kconstanteditor.cpp
index dbcd3c18..c2017c8a 100644
--- a/kmplot/kmplot/kconstanteditor.cpp
+++ b/kmplot/kmplot/kconstanteditor.cpp
@@ -199,7 +199,7 @@ void KConstantEditor::editConstantSlot()
int index = 0;
for( TQValueVector<Ufkt>::iterator it = m_view->parser()->ufkt.begin(); it != m_view->parser()->ufkt.end(); ++it)
{
- if( it->fstr.tqcontains(constant)!=0 )
+ if( it->fstr.contains(constant)!=0 )
m_view->parser()->reparse(index); //reparsing the function
++index;
}
diff --git a/kmplot/kmplot/keditparametric.cpp b/kmplot/kmplot/keditparametric.cpp
index 4136a8f8..67ee0421 100644
--- a/kmplot/kmplot/keditparametric.cpp
+++ b/kmplot/kmplot/keditparametric.cpp
@@ -103,7 +103,7 @@ void KEditParametric::setWidgets()
void KEditParametric::accept()
{
- if ( kLineEditXFunction->text().tqcontains('y') != 0 || kLineEditYFunction->text().tqcontains('y') != 0)
+ if ( kLineEditXFunction->text().contains('y') != 0 || kLineEditYFunction->text().contains('y') != 0)
{
KMessageBox::error( this, i18n( "Recursive function not allowed"));
kLineEditXFunction->setFocus();
diff --git a/kmplot/kmplot/kminmax.cpp b/kmplot/kmplot/kminmax.cpp
index 659710d9..3f8db2c8 100644
--- a/kmplot/kmplot/kminmax.cpp
+++ b/kmplot/kmplot/kminmax.cpp
@@ -258,13 +258,13 @@ void KMinMax::cmdFind_clicked()
TQString function( list->currentText() );
char p_mode = 0;
- if ( function.tqcontains('\'') == 1)
+ if ( function.contains('\'') == 1)
{
p_mode = 1;
int pos = function.find('\'');
function.remove(pos,1);
}
- else if ( function.tqcontains('\'') == 2)
+ else if ( function.contains('\'') == 2)
{
p_mode = 2;
int pos = function.find('\'');
@@ -352,13 +352,13 @@ void KMinMax::list_highlighted(TQListBoxItem* item)
}
TQString function( list->currentText() );
char p_mode = 0;
- if ( function.tqcontains('\'') == 1)
+ if ( function.contains('\'') == 1)
{
p_mode = 1;
int pos = function.find('\'');
function.remove(pos,1);
}
- else if ( function.tqcontains('\'') == 2)
+ else if ( function.contains('\'') == 2)
{
p_mode = 2;
int pos = function.find('\'');
@@ -390,13 +390,13 @@ void KMinMax::cmdParameter_clicked()
{
TQString function( list->currentText() );
char p_mode = 0;
- if ( function.tqcontains('\'') == 1)
+ if ( function.contains('\'') == 1)
{
p_mode = 1;
int pos = function.find('\'');
function.remove(pos,1);
}
- else if ( function.tqcontains('\'') == 2)
+ else if ( function.contains('\'') == 2)
{
p_mode = 2;
int pos = function.find('\'');
diff --git a/kmplot/kmplot/kmplot.cpp b/kmplot/kmplot/kmplot.cpp
index 8cc03beb..e6f71013 100644
--- a/kmplot/kmplot/kmplot.cpp
+++ b/kmplot/kmplot/kmplot.cpp
@@ -82,7 +82,7 @@ KmPlot::KmPlot( KCmdLineArgs* args)
}
if (!initialGeometrySet())
- resize( TQSize(450, 520).expandedTo(tqminimumSizeHint()));
+ resize( TQSize(450, 520).expandedTo(minimumSizeHint()));
// apply the saved mainwindow settings, if any, and ask the mainwindow
// to automatically save settings if changed: window size, toolbar
diff --git a/kmplot/kmplot/kprinterdlg.cpp b/kmplot/kmplot/kprinterdlg.cpp
index 91036668..aa74a7b5 100644
--- a/kmplot/kmplot/kprinterdlg.cpp
+++ b/kmplot/kmplot/kprinterdlg.cpp
@@ -37,16 +37,16 @@ KPrinterDlg::KPrinterDlg( TQWidget *parent, const char *name )
: KPrintDialogPage( parent, name )
{
setTitle( i18n( "KmPlot Options" ) );
- TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
- tqlayout->setMargin( KDialog::marginHint() );
- tqlayout->setSpacing( KDialog::spacingHint() );
+ TQVBoxLayout *layout = new TQVBoxLayout( this );
+ layout->setMargin( KDialog::marginHint() );
+ layout->setSpacing( KDialog::spacingHint() );
printHeaderTable = new TQCheckBox( i18n( "Print header table" ), this );
transparent_background = new TQCheckBox( i18n( "Transparent background" ), this );
- tqlayout->addWidget( printHeaderTable );
- tqlayout->addWidget( transparent_background );
- tqlayout->addStretch( 1 );
+ layout->addWidget( printHeaderTable );
+ layout->addWidget( transparent_background );
+ layout->addStretch( 1 );
}
void KPrinterDlg::getOptions( TQMap<TQString, TQString>& opts, bool include_def )
diff --git a/kmplot/kmplot/parser.cpp b/kmplot/kmplot/parser.cpp
index efa391ac..ed064b85 100644
--- a/kmplot/kmplot/parser.cpp
+++ b/kmplot/kmplot/parser.cpp
@@ -190,7 +190,7 @@ double Parser::eval(TQString str)
fix_expression(str,0);
- if ( str.tqcontains('y')!=0)
+ if ( str.contains('y')!=0)
{
err=9;
delete []stack;
@@ -520,7 +520,7 @@ void Parser::fix_expression(TQString &str, int const pos)
}
}
TQString str_end = str.mid(pos);
- str_end = str_end.tqreplace(m_decimalsymbol, "."); //tqreplace the locale decimal symbol with a '.'
+ str_end = str_end.replace(m_decimalsymbol, "."); //replace the locale decimal symbol with a '.'
str.truncate(pos);
str.append(str_end);
//kdDebug() << "str:" << str << endl;
@@ -1006,7 +1006,7 @@ int Parser::parserError(bool showMessageBox)
TQString Parser::number( double value )
{
TQString str = TQString::number( value, 'g', 6 );
- str.tqreplace( 'e', "*10^" );
+ str.replace( 'e', "*10^" );
// kDebug() << "returning str="<<str<<endl;
return str;
}
diff --git a/kmplot/kmplot/parser.h b/kmplot/kmplot/parser.h
index a07810bb..13098039 100644
--- a/kmplot/kmplot/parser.h
+++ b/kmplot/kmplot/parser.h
@@ -246,7 +246,7 @@ private:
* \li 9 => recursive function call
* \li 10 => didn't found the wanted constant
* \li 11 => emtpy function
- * \li 12 => function name tqcontains a capital letter
+ * \li 12 => function name contains a capital letter
* \li 13 => function could not be found
* \li 14 => evalation expression may not use user definded constants
*/
@@ -254,7 +254,7 @@ private:
/// Position where the error occurred.
int errpos;
- void fix_expression(TQString &, int const); ///adding extra *-characters, remove spaces and tqreplace the locale .-character with '.'
+ void fix_expression(TQString &, int const); ///adding extra *-characters, remove spaces and replace the locale .-character with '.'
void ps_init(),
heir1(),
diff --git a/kmplot/kmplot/qconstanteditor.ui b/kmplot/kmplot/qconstanteditor.ui
index a0139aa0..92baf7e5 100644
--- a/kmplot/kmplot/qconstanteditor.ui
+++ b/kmplot/kmplot/qconstanteditor.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>QConstantEditor</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -133,7 +133,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>147</height>
@@ -193,7 +193,7 @@
<slot>newNewConstantSlot()</slot>
<slot>varlist_doubleClicked( QListViewItem * )</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klistview.h</includehint>
</includehints>
diff --git a/kmplot/kmplot/qeditconstant.ui b/kmplot/kmplot/qeditconstant.ui
index 301a1c46..1d9bdb0a 100644
--- a/kmplot/kmplot/qeditconstant.ui
+++ b/kmplot/kmplot/qeditconstant.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>QEditConstant</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -40,7 +40,7 @@
</widget>
<widget class="QLayoutWidget" row="2" column="0" rowspan="1" colspan="2">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<hbox>
<property name="name">
@@ -67,7 +67,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>71</width>
<height>20</height>
@@ -131,7 +131,7 @@
<slots>
<slot>txtVariable_lostFocus()</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/kmplot/kmplot/qeditparametric.ui b/kmplot/kmplot/qeditparametric.ui
index d66f7c75..b41573ab 100644
--- a/kmplot/kmplot/qeditparametric.ui
+++ b/kmplot/kmplot/qeditparametric.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>QEditParametric</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -48,7 +48,7 @@
<property name="text">
<string>Name:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="buddy" stdset="0">
@@ -93,7 +93,7 @@ The name of a function must be unique. If you leave this line empty KmPlot will
</widget>
<widget class="QLayoutWidget" row="2" column="0">
<property name="name">
- <cstring>tqlayout9</cstring>
+ <cstring>layout9</cstring>
</property>
<hbox>
<property name="name">
@@ -156,7 +156,7 @@ Example: sin(t)</string>
</widget>
<widget class="QLayoutWidget" row="1" column="0">
<property name="name">
- <cstring>tqlayout8</cstring>
+ <cstring>layout8</cstring>
</property>
<hbox>
<property name="name">
@@ -340,7 +340,7 @@ Example: sin(t)</string>
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -531,7 +531,7 @@ Example: sin(t)</string>
<slots>
<slot>slotHelp()</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/kmplot/kmplot/qeditpolar.ui b/kmplot/kmplot/qeditpolar.ui
index 9d3d5522..e61c5c6d 100644
--- a/kmplot/kmplot/qeditpolar.ui
+++ b/kmplot/kmplot/qeditpolar.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>QEditPolar</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -218,7 +218,7 @@ Example: loop(angle)=ln(angle)</string>
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -395,7 +395,7 @@ Example: loop(angle)=ln(angle)</string>
<slots>
<slot>slotHelp()</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>kcolorbutton.h</includehint>
diff --git a/kmplot/kmplot/qminmax.ui b/kmplot/kmplot/qminmax.ui
index 338d641a..d828cbd6 100644
--- a/kmplot/kmplot/qminmax.ui
+++ b/kmplot/kmplot/qminmax.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>QMinMax</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -51,7 +51,7 @@
<property name="text">
<string>Search between the x-value:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
</widget>
@@ -62,7 +62,7 @@
<property name="text">
<string>and:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
</widget>
@@ -138,5 +138,5 @@
</widget>
</grid>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kmplot/kmplot/qparametereditor.ui b/kmplot/kmplot/qparametereditor.ui
index 779d1393..619f4fd7 100644
--- a/kmplot/kmplot/qparametereditor.ui
+++ b/kmplot/kmplot/qparametereditor.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>QParameterEditor</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -119,7 +119,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>80</height>
@@ -153,7 +153,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>21</height>
@@ -181,5 +181,5 @@
</widget>
</grid>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kmplot/kmplot/settingspagecolor.ui b/kmplot/kmplot/settingspagecolor.ui
index a883f1ae..e8e85323 100644
--- a/kmplot/kmplot/settingspagecolor.ui
+++ b/kmplot/kmplot/settingspagecolor.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>SettingsPageColor</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -33,7 +33,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<grid>
<property name="name">
@@ -101,7 +101,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -123,7 +123,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout19</cstring>
+ <cstring>layout19</cstring>
</property>
<hbox>
<property name="name">
@@ -131,7 +131,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout16</cstring>
+ <cstring>layout16</cstring>
</property>
<grid>
<property name="name">
@@ -274,7 +274,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -283,7 +283,7 @@
</spacer>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout17</cstring>
+ <cstring>layout17</cstring>
</property>
<grid>
<property name="name">
@@ -428,7 +428,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -455,5 +455,5 @@
<tabstop>kcfg_Color8</tabstop>
<tabstop>kcfg_Color9</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kmplot/kmplot/settingspagecoords.ui b/kmplot/kmplot/settingspagecoords.ui
index 7e2a8274..cf2826b3 100644
--- a/kmplot/kmplot/settingspagecoords.ui
+++ b/kmplot/kmplot/settingspagecoords.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>SettingsPageCoords</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -33,7 +33,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout23</cstring>
+ <cstring>layout23</cstring>
</property>
<hbox>
<property name="name">
@@ -131,7 +131,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout20</cstring>
+ <cstring>layout20</cstring>
</property>
<grid>
<property name="name">
@@ -277,7 +277,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout20_2</cstring>
+ <cstring>layout20_2</cstring>
</property>
<grid>
<property name="name">
@@ -335,7 +335,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout24</cstring>
+ <cstring>layout24</cstring>
</property>
<hbox>
<property name="name">
@@ -375,7 +375,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout25</cstring>
+ <cstring>layout25</cstring>
</property>
<hbox>
<property name="name">
@@ -415,7 +415,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout26</cstring>
+ <cstring>layout26</cstring>
</property>
<hbox>
<property name="name">
@@ -458,7 +458,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout22</cstring>
+ <cstring>layout22</cstring>
</property>
<grid>
<property name="name">
@@ -544,7 +544,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>30</height>
@@ -626,7 +626,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout24</cstring>
+ <cstring>layout24</cstring>
</property>
<hbox>
<property name="name">
@@ -677,7 +677,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -751,7 +751,7 @@
<tabstop>radioButton14</tabstop>
<tabstop>kcfg_GridLineWidth</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/kmplot/kmplot/settingspagefonts.ui b/kmplot/kmplot/settingspagefonts.ui
index 10c6b80a..e5f80ccd 100644
--- a/kmplot/kmplot/settingspagefonts.ui
+++ b/kmplot/kmplot/settingspagefonts.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>SettingsPageFonts</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -26,7 +26,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>110</height>
@@ -119,7 +119,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kfontcombo.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/kmplot/kmplot/settingspageprecision.ui b/kmplot/kmplot/settingspageprecision.ui
index a3711c76..25f732ce 100644
--- a/kmplot/kmplot/settingspageprecision.ui
+++ b/kmplot/kmplot/settingspageprecision.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>SettingsPagePrecision</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -26,7 +26,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>29</height>
@@ -149,7 +149,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>81</width>
<height>20</height>
@@ -212,7 +212,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<hbox>
<property name="name">
@@ -268,7 +268,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/kmplot/kmplot/settingspagescaling.ui b/kmplot/kmplot/settingspagescaling.ui
index f004b5ac..222359ba 100644
--- a/kmplot/kmplot/settingspagescaling.ui
+++ b/kmplot/kmplot/settingspagescaling.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>SettingsPageScaling</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -18,7 +18,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout35</cstring>
+ <cstring>layout35</cstring>
</property>
<hbox>
<property name="name">
@@ -396,7 +396,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>91</height>
@@ -411,5 +411,5 @@
<tabstop>kcfg_YScaling</tabstop>
<tabstop>kcfg_YPrinting</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kmplot/kmplot/sliderwindow.ui b/kmplot/kmplot/sliderwindow.ui
index daf21345..deff716a 100644
--- a/kmplot/kmplot/sliderwindow.ui
+++ b/kmplot/kmplot/sliderwindow.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>SliderWindow</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -23,7 +23,7 @@
<property name="name">
<cstring>slider</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>200</width>
<height>0</height>
@@ -60,7 +60,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>45</width>
<height>0</height>
@@ -69,7 +69,7 @@
<property name="text">
<string>0</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -83,5 +83,5 @@
<slot>setNum(int)</slot>
</connection>
</connections>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kmplot/kmplot/xparser.cpp b/kmplot/kmplot/xparser.cpp
index 7d34e58f..18d9a3b3 100644
--- a/kmplot/kmplot/xparser.cpp
+++ b/kmplot/kmplot/xparser.cpp
@@ -648,7 +648,7 @@ int XParser::addFunction(const TQString &f_str)
fixFunctionName(added_function);
if ( added_function.at(0)== 'x' || added_function.at(0)== 'y') //TODO: Make it possible to define parametric functions
return -1;
- if ( added_function.tqcontains('y') != 0)
+ if ( added_function.contains('y') != 0)
return -1;
int const id = addfkt( added_function );
if (id==-1)
diff --git a/kmplot/kmplot/MainDlg.h b/kmplot/kmplot/MainDlg.h
index 69520f2a..7b4d83bf 100644
--- a/kmplot/kmplot/MainDlg.h
+++ b/kmplot/kmplot/MainDlg.h
@@ -64,7 +64,7 @@ class BrowserExtension;
/** @short This is the main window of KmPlot.
*
- * Its central widget view tqcontains the parser, accessable via its parser() function.
+ * Its central widget view contains the parser, accessable via its parser() function.
* @see View, View::m_parser, View::parser
*/
class MainDlg : public KParts::ReadOnlyPart, virtual public MainDlgIface
@@ -73,11 +73,11 @@ class MainDlg : public KParts::ReadOnlyPart, virtual public MainDlgIface
public:
/** Constuctor.
* @param tqparentWidget parent widget for this part
* @param parent parent object
* @param name name of this dialog
*/
- MainDlg(TQWidget *tqparentWidget, const char *, TQObject *parent, const char *name);
+ MainDlg(TQWidget *parentWidget, const char *, TQObject *parent, const char *name);
/// Cleaning up a bit.
virtual ~MainDlg();
/// This class needs access to private members, too.
@@ -219,7 +219,7 @@ class KmPlotPartFactory : public KParts::Factory
public:
KmPlotPartFactory();
virtual ~KmPlotPartFactory();
- virtual KParts::Part* createPartObject( TQWidget *tqparentWidget, const char *widgetName,
+ virtual KParts::Part* createPartObject( TQWidget *parentWidget, const char *widgetName,
TQObject *parent, const char *name,
const char *classname, const TQStringList &args );
static KInstance* instance();
@@ -73,11 +73,11 @@ class MainDlg : public KParts::ReadOnlyPart, virtual public MainDlgIface
public:
/** Constuctor.
- * @param tqparentWidget parent widget for this part
+ * @param parentWidget parent widget for this part
* @param parent parent object
* @param name name of this dialog